summaryrefslogtreecommitdiff
path: root/src/mem
diff options
context:
space:
mode:
authorSteve Reinhardt <steve.reinhardt@amd.com>2009-04-20 18:54:02 -0700
committerSteve Reinhardt <steve.reinhardt@amd.com>2009-04-20 18:54:02 -0700
commit3083268d60ba28cf011eadd6d6e4f400e6686cc3 (patch)
tree7dbd37a140a59acacaf46101b7ea1e8fb5a8dbfe /src/mem
parent7f8ea68a309790821d81500d1ba15d4ceef25933 (diff)
downloadgem5-3083268d60ba28cf011eadd6d6e4f400e6686cc3.tar.xz
request: rename INST_READ to INST_FETCH.
Diffstat (limited to 'src/mem')
-rw-r--r--src/mem/cache/prefetch/base.cc2
-rw-r--r--src/mem/request.hh8
2 files changed, 5 insertions, 5 deletions
diff --git a/src/mem/cache/prefetch/base.cc b/src/mem/cache/prefetch/base.cc
index 365ce6727..f20a306cb 100644
--- a/src/mem/cache/prefetch/base.cc
+++ b/src/mem/cache/prefetch/base.cc
@@ -170,7 +170,7 @@ BasePrefetcher::getPacket()
Tick
BasePrefetcher::notify(PacketPtr &pkt, Tick time)
{
- if (!pkt->req->isUncacheable() && !(pkt->req->isInstRead() && onlyData)) {
+ if (!pkt->req->isUncacheable() && !(pkt->req->isInstFetch() && onlyData)) {
// Calculate the blk address
Addr blk_addr = pkt->getAddr() & ~(Addr)(blkSize-1);
diff --git a/src/mem/request.hh b/src/mem/request.hh
index 965e58b3b..5fa682f2b 100644
--- a/src/mem/request.hh
+++ b/src/mem/request.hh
@@ -86,8 +86,8 @@ class Request : public FastAlloc
static const FlagsType EVICT_NEXT = 0x00020000;
/** The request should ignore unaligned access faults */
static const FlagsType NO_ALIGN_FAULT = 0x00040000;
- /** The request was an instruction read. */
- static const FlagsType INST_READ = 0x00080000;
+ /** The request was an instruction fetch. */
+ static const FlagsType INST_FETCH = 0x00080000;
/** This request is for a memory swap. */
static const FlagsType MEM_SWAP = 0x00100000;
static const FlagsType MEM_SWAP_COND = 0x00200000;
@@ -98,7 +98,7 @@ class Request : public FastAlloc
/** These flags are *not* cleared when a Request object is reused
(assigned a new address). */
- static const FlagsType STICKY_FLAGS = INST_READ;
+ static const FlagsType STICKY_FLAGS = INST_FETCH;
private:
typedef uint8_t PrivateFlagsType;
@@ -430,7 +430,7 @@ class Request : public FastAlloc
/** Accessor Function to Check Cacheability. */
bool isUncacheable() const { return flags.isSet(UNCACHEABLE); }
- bool isInstRead() const { return flags.isSet(INST_READ); }
+ bool isInstFetch() const { return flags.isSet(INST_FETCH); }
bool isLLSC() const { return flags.isSet(LLSC); }
bool isLocked() const { return flags.isSet(LOCKED); }
bool isSwap() const { return flags.isSet(MEM_SWAP|MEM_SWAP_COND); }